@@ -55,6 +55,28 @@ class APIError(ZepClientError):
         super().__init__(message=message, response_data=response_data)
 
 
+class AuthError(ZepClientError):
+    """
+    Raised when API authentication fails.
+
+    Inherits from APIError.
+    """
+
+    def __init__(
+        self,
+        response: Union[httpx.Response, None] = None,
+        message: str = "Authentication error",
+    ) -> None:
+        if response:
+            response_data = {
+                "status_code": response.status_code,
+                "message": response.text,
+            }
+        else:
+            response_data = None
+        super().__init__(message=message, response_data=response_data)
+
+
 class NotFoundError(ZepClientError):
     """
     Raised when the API response contains no results.
@@ -64,3 +86,17 @@ class NotFoundError(ZepClientError):
 
     def __init__(self, message: str) -> None:
         super().__init__(message)
+
+
+def handle_response(
+    response: httpx.Response, missing_doc: Optional[str] = None
+) -> None:
+    missing_doc = missing_doc or "No query results found"
+    if response.status_code == 404:
+        raise NotFoundError(missing_doc)
+
+    if response.status_code == 401:
+        raise AuthError(response)
+
+    if not (200 <= response.status_code <= 299):
+        raise APIError(response)
